define(['../constants/hotkeys-ids.js'], function (HOTKEYS) {

	// List of Toggle hotkeys that we're listening for
	const toggle_hotkeys = {};
	
	// List of Hold hotkeys that we're listening for
	const hold_hotkeys = {};
	
	
	/**
	 * Listen to any Toggle hotkey press, and execute any stored custom action
	 */
	overwolf.settings.hotkeys.onPressed.addListener(function(e){
		if(e.name in toggle_hotkeys) toggle_hotkeys[e.name]();
	});
	
	
	/**
	 * Listen to any Hold hotkey press, and execute any stored custom action
	 */
	overwolf.settings.hotkeys.onHold.addListener(function(e){
		if(e.name in hold_hotkeys) hold_hotkeys[e.name](e.state);
	});
	
	function _getHotkeyNew(hotkeyId, callback) {
		overwolf.settings.hotkeys.get(function (data) {
			if (!data || data.success !== true) {
				setTimeout(function () {
					_getHotkeyNew(hotkeyId, callback);
				}, 2000);
			} else {
				
				var result = false;
				var game_id = '10826'; // Siege's Game ID
				
				if('games' in data && game_id in data.games) {
				
					data.games[game_id].forEach(function(hk){
						if(hk.name == hotkeyId) {
							
							result = hk.binding;
							
						}
					});
					
				}
				
				callback(result);
			}
		});
	}

	/**
	 * set custom action for a Toggle hotkey id
	 * @param hotkeyId
	 * @param action
	 * @private
	 */
	function _setToggleHotkey(hotkeyId, action) {
		toggle_hotkeys[hotkeyId] = action;
	}
	
	/**
	 * set custom action for a Hold hotkey id
	 * @param hotkeyId
	 * @param action
	 * @private
	 */
	function _setHoldHotkey(hotkeyId, action) {
		hold_hotkeys[hotkeyId] = action;
	}

	function getToggleHotkey() {
		return new Promise((resolve, reject) => {
			_getHotkeyNew(HOTKEYS.R6SB_TOGGLE, function (result) {
				resolve(result);
			});
		});
	}

	function setToggleHotkey(action) {
		_setToggleHotkey(HOTKEYS.R6SB_TOGGLE,action);
	}
	
	function getR6AMultimonitorToggleHotkey() {
		return new Promise((resolve, reject) => {
			_getHotkeyNew(HOTKEYS.R6A_MULTIMONITOR, function (result) {
				resolve(result);
			});
		});
	}

	function setR6AMultimonitorToggleHotkey(action) {
		_setToggleHotkey(HOTKEYS.R6A_MULTIMONITOR,action);
	}
	
	function getR6MSEditorToggleHotkey() {
		return new Promise((resolve, reject) => {
			_getHotkeyNew(HOTKEYS.R6MS_EDITOR, function (result) {
				resolve(result);
			});
		});
	}

	function setR6MSEditorToggleHotkey(action) {
		_setToggleHotkey(HOTKEYS.R6MS_EDITOR,action);
	}

	function getESEHotkey() {
		return new Promise((resolve, reject) => {
			_getHotkeyNew(HOTKEYS.R6UI_HOLD, function (result) {
				resolve(result);
			});
		});
	}

	function setESEHotkey(action) {
		_setHoldHotkey(HOTKEYS.R6UI_HOLD,action);
	}

	function addHotkeyChangeListener(listener) {
		overwolf.settings.hotkeys.onChanged.addListener(listener);
	}
	
	return {
		getToggleHotkey,
		setToggleHotkey,
		getR6AMultimonitorToggleHotkey,
		setR6AMultimonitorToggleHotkey,
		getR6MSEditorToggleHotkey,
		setR6MSEditorToggleHotkey,
		getESEHotkey,
		setESEHotkey,
		addHotkeyChangeListener
	};
});
