define([ ], function () {

	/**
	 * obtain a window object by a name as declared in the manifest
	 * this is required in order to create the window before calling other APIs
	 * on that window
	 * @param name
	 * @returns {Promise<any>}
	 */
	function obtainWindow(name) {
		return new Promise((resolve, reject) => {
			overwolf.windows.obtainDeclaredWindow(name, (result) => {
				if (result.status !== 'success') {
					console.log('window-service ERROR for '+name);
					console.log(JSON.stringify(result));
					return reject(result);
				}
				resolve(result);
			});
		});
	}

	/**
	 * restore a window by name
	 * @param name
	 * @returns {Promise<any>}
	 */
	function restore(name) {
		return new Promise(async (resolve, reject) => {
			try {
				await obtainWindow(name);
				overwolf.windows.restore(name, (result) => {
					if (result.status === 'success') {
						resolve();
					} else {
						console.log('window-service ERROR for '+name);
						console.log(JSON.stringify(result));
						reject(result);
					}
				});
			} catch (e) {
				reject(e)
			}
		});
	}

	/**
	 * minimize a window by name
	 * @param name
	 * @returns {Promise<any>}
	 */
	function minimize(name) {
		return new Promise(async (resolve, reject) => {
			try {
				await obtainWindow(name);
				overwolf.windows.minimize(name, (result) => {
					if (result.status === 'success') {
						resolve();
					} else {
						console.log('window-service ERROR for '+name);
						console.log(JSON.stringify(result));
						reject(result);
					}
				});
			} catch (e) {
				reject(e)
			}
		});
	}

	/**
	 * maximize a window by name
	 * @param name
	 * @returns {Promise<any>}
	 */
	function maximize(name) {
		return new Promise(async (resolve, reject) => {
			try {
				await obtainWindow(name);
				overwolf.windows.maximize(name, (result) => {
					if (result.status === 'success') {
						resolve();
					} else {
						console.log('window-service ERROR for '+name);
						console.log(JSON.stringify(result));
						reject(result);
					}
				});
			} catch (e) {
				reject(e)
			}
		});
	}
	
	/**
	 * hide a window by name
	 * @param name
	 * @returns {Promise<any>}
	 */
	function hide(name) {
		return new Promise(async (resolve, reject) => {
			try {
				await obtainWindow(name);
				overwolf.windows.hide(name, (result) => {
					if (result.status === 'success') {
						resolve();
					} else {
						console.log('window-service ERROR for '+name);
						console.log(JSON.stringify(result));
						reject(result);
					}
				});
			} catch (e) {
				reject(e)
			}
		});
	}

	/**
	 * Returns a map (window name, object) of all open windows.
	 * @returns {Promise<any>}
	 */
	function getOpenWindows() {
		return new Promise(async (resolve, reject) => {
			try {
				overwolf.windows.getOpenWindows((result) => {
					resolve(result);
				});
			} catch (e) {
				console.log('window-service ERROR for getOpenWindows');
				reject(e);
			}
		});
	}

	/**
	 * Close a window
	 * @param windowName
	 * @returns {Promise<any>}
	 */
	function close(windowName) {
		return new Promise(async (resolve, reject) => {
			try {
				overwolf.windows.close(windowName, () => {
					resolve();
				});
			} catch (e) {
				console.log('window-service ERROR for close('+windowName+')');
				reject(e);
			}
		});
	}

	/**
	 * get state of the window
	 * @returns {Promise<*>}
	 */
	async function getWindowState(name) {
		return new Promise(async (resolve, reject) => {
			try {
				overwolf.windows.getWindowState(name, (state) => {
					if (state.status === 'success') {
						resolve(state.window_state_ex);
					} else {
						console.log('window-service ERROR for getWindowState('+name+')');
						reject(result);
					}
				})
			} catch (e){
				reject(e);
			}
		});
	}
	
	return {
		restore,
		minimize,
		maximize,
		hide,
		obtainWindow,
		getOpenWindows,
		close,
		getWindowState
	}
});